#!/bin/sh -e

# called by uscan with '--upstream-version' <version> <file>

DIR=jcodings-$2

git clone http://github.com/jruby/jcodings.git $DIR
(cd $DIR && git checkout $2)

tar cfz ../jcodings_$2.orig.tar.gz --exclude .git $DIR

rm -rf $DIR ../$2
